@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.15 00:00:00                  #
+# Updated Date: 2025.08.22 10:00:00                  #
 # ================================================== #
 
 import os
@@ -24,6 +24,15 @@ if platform.system() == 'Windows':
 
 # enable debug logging
 # os.environ["QT_LOGGING_RULES"] = "*.debug=true"
+# os.environ["QTWEBENGINE_REMOTE_DEBUGGING"] = "9222"
+"""
+os.environ["QTWEBENGINE_CHROMIUM_FLAGS"] = (
+    "--renderer-process-limit=1 "
+    "--process-per-site "
+    "--enable-precise-memory-info "
+    "--js-flags=--expose-gc"
+)
+"""
 
 _original_open = builtins.open
 
@@ -77,6 +86,7 @@ from pygpt_net.plugin.telegram import Plugin as TelegramPlugin
 from pygpt_net.plugin.slack import Plugin as SlackPlugin
 from pygpt_net.plugin.github import Plugin as GithubPlugin
 from pygpt_net.plugin.bitbucket import Plugin as BitbucketPlugin
+from pygpt_net.plugin.server import Plugin as ServerPlugin
 
 # agents (Llama-index)
 # from pygpt_net.provider.agents.llama_index.legacy.openai import OpenAIAgent
@@ -87,6 +97,7 @@ from pygpt_net.provider.agents.llama_index.openai_workflow import OpenAIAgent as
 # from pygpt_net.provider.agents.llama_index.legacy.react import ReactAgent
 from pygpt_net.provider.agents.llama_index.react_workflow import ReactWorkflowAgent
 from pygpt_net.provider.agents.llama_index.codeact_workflow import CodeActAgent
+from pygpt_net.provider.agents.llama_index.supervisor_workflow import SupervisorAgent as LlamaSupervisorAgent
 from pygpt_net.provider.agents.openai.agent import Agent as OpenAIAgentsBase
 from pygpt_net.provider.agents.openai.agent_with_experts import Agent as OpenAIAgentsExperts
 from pygpt_net.provider.agents.openai.agent_with_experts_feedback import Agent as OpenAIAgentsExpertsFeedback
@@ -95,6 +106,7 @@ from pygpt_net.provider.agents.openai.bot_researcher import Agent as OpenAIAgent
 from pygpt_net.provider.agents.openai.agent_planner import Agent as OpenAIAgentPlanner
 from pygpt_net.provider.agents.openai.evolve import Agent as OpenAIAgentsEvolve
 from pygpt_net.provider.agents.openai.agent_b2b import Agent as OpenAIAgentsB2B
+from pygpt_net.provider.agents.openai.supervisor import Agent as OpenAIAgentSupervisor
 
 # LLM wrapper providers (langchain, llama-index, embeddings)
 from pygpt_net.provider.llms.anthropic import AnthropicLLM
@@ -394,6 +406,7 @@ def run(**kwargs):
     launcher.add_plugin(SlackPlugin())
     launcher.add_plugin(GithubPlugin())
     launcher.add_plugin(BitbucketPlugin())
+    launcher.add_plugin(ServerPlugin())
 
     # register custom plugins
     plugins = kwargs.get('plugins', None)
@@ -444,6 +457,7 @@ def run(**kwargs):
     # launcher.add_agent(ReactAgent())  # llama-index
     launcher.add_agent(ReactWorkflowAgent())  # llama-index
     launcher.add_agent(CodeActAgent())  # llama-index
+    launcher.add_agent(LlamaSupervisorAgent())  # llama-index
     launcher.add_agent(OpenAIAgentsBase())  # openai-agents
     launcher.add_agent(OpenAIAgentsExperts())  # openai-agents
     launcher.add_agent(OpenAIAgentFeedback())  # openai-agents
@@ -452,6 +466,7 @@ def run(**kwargs):
     launcher.add_agent(OpenAIAgentsExpertsFeedback())  # openai-agents
     launcher.add_agent(OpenAIAgentsEvolve())  # openai-agents
     launcher.add_agent(OpenAIAgentsB2B())  # openai-agents
+    launcher.add_agent(OpenAIAgentSupervisor())  # openai-agents
 
     # register custom agents
     agents = kwargs.get('agents', None)
