@@ -6,12 +6,14 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.22 22:00:00                  #
+# Updated Date: 2025.08.11 19:00:00                  #
 # ================================================== #
 
 import copy
 from typing import Optional, Any, Dict
 
+from PySide6.QtCore import QTimer
+
 from pygpt_net.core.events import Event
 from pygpt_net.utils import trans
 
@@ -60,13 +62,14 @@ class Editor:
         self.window.ui.add_hook("update.config.ctx.records.folders.top", self.hook_update)
         self.window.ui.add_hook("update.config.layout.density", self.hook_update)
         self.window.ui.add_hook("update.config.layout.tooltips", self.hook_update)
-        self.window.ui.add_hook("update.config.img_dialog_open", self.hook_update)
         self.window.ui.add_hook("update.config.access.voice_control", self.hook_update)
         self.window.ui.add_hook("update.config.debug", self.hook_update)
         self.window.ui.add_hook("update.config.notepad.num", self.hook_update)
         self.window.ui.add_hook("update.config.render.code_syntax", self.hook_update)
         self.window.ui.add_hook("update.config.theme.style", self.hook_update)
         self.window.ui.add_hook("update.config.llama.idx.chat.agent.render.all", self.hook_update)
+        self.window.ui.add_hook("update.config.audio.input.backend", self.hook_update)
+        self.window.ui.add_hook("update.config.audio.output.backend", self.hook_update)
         # self.window.ui.add_hook("llama.idx.storage", self.hook_update)  # vector store update
         # self.window.ui.add_hook("update.config.llama.idx.list", self.hook_update)
 
@@ -317,7 +320,7 @@ class Editor:
         # update ctx limit
         elif key.startswith('ctx.records.limit') and caller == "slider":
             self.window.core.config.set(key, value)
-            self.window.controller.ctx.update(True, False)
+            QTimer.singleShot(1000, lambda: self.window.controller.ctx.update(True, False))
 
         # update layout density
         elif key == "layout.density" and caller == "slider":
@@ -325,16 +328,43 @@ class Editor:
             self.window.controller.theme.reload()
             self.window.controller.theme.menu.update_density()
 
-        # toggle image dialog auto-open
-        elif key == "img_dialog_open":
-            self.window.core.config.set(key, value)
-            self.window.ui.nodes['dialog.image.open.toggle'].setChecked(value)
-
         # debug: menu
         elif key == "debug":
             self.window.core.config.set(key, value)
             self.window.controller.debug.toggle_menu()
 
+        # audio devices
+        elif key == "audio.input.backend":
+            self.window.core.config.set(key, value)
+            items = self.window.controller.config.placeholder.get_audio_input_devices()
+            option = self.options.get("audio.input.device", {})
+            default_id, _ = self.window.core.audio.get_default_input_device()
+            if default_id is None:
+                default_id = 0
+            self.window.controller.config.update_list(option, "config", "audio.input.device", items)
+            self.window.controller.config.apply_value(
+                parent_id='config',
+                key='audio.input.device',
+                option=option,
+                value=str(default_id)  # default device,
+            )
+            self.window.core.config.set("audio.input.device", str(default_id))  # reset to default device
+        elif key == "audio.output.backend":
+            self.window.core.config.set(key, value)
+            items = self.window.controller.config.placeholder.get_audio_output_devices()
+            option = self.options.get("audio.output.device", {})
+            default_id, _ = self.window.core.audio.get_default_output_device()
+            if default_id is None:
+                default_id = 0
+            self.window.controller.config.update_list(option, "config", "audio.output.device", items)
+            self.window.controller.config.apply_value(
+                parent_id='config',
+                key='audio.output.device',
+                option=option,
+                value=str(default_id)  # default device,
+            )
+            self.window.core.config.set("audio.output.device", str(default_id))  # reset to default device
+
     def toggle_collapsed(
             self,
             id: str,
