@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.14 13:00:00                  #
+# Updated Date: 2025.08.21 07:00:00                  #
 # ================================================== #
 
 import asyncio
@@ -39,6 +39,7 @@ class Runner:
     APPEND_SYSTEM_PROMPT_TO_MSG = [
         "react",  # llama-index
     ]
+    ADDITIONAL_CONTEXT_PREFIX = "ADDITIONAL CONTEXT:"
 
     def __init__(self, window=None):
         """
@@ -76,9 +77,13 @@ class Runner:
             return True  # abort if stopped
 
         agent_id = extra.get("agent_provider", "openai")
-        verbose = self.window.core.config.get("agent.llama.verbose", False)
+        verbose = self.is_verbose()
 
         try:
+            # first, check if agent exists
+            if not self.window.core.agents.provider.has(agent_id):
+                raise Exception(f"Agent not found: {agent_id}")
+
             # prepare input ctx
             ctx = context.ctx
             ctx.extra["agent_input"] = True  # mark as user input
@@ -102,14 +107,15 @@ class Runner:
                 vector_store_idx = preset.idx
 
             # tools
-            self.window.core.agents.tools.context = context
-            self.window.core.agents.tools.agent_idx = vector_store_idx
+            agent_tools = self.window.core.agents.tools
+            agent_tools.set_context(context)
+            agent_tools.set_idx(vector_store_idx)
 
-            tools = self.window.core.agents.tools.prepare(context, extra, force=True)
-            function_tools = self.window.core.agents.tools.get_function_tools(ctx, extra, force=True)
-            plugin_tools = self.window.core.agents.tools.get_plugin_tools(context, extra, force=True)
-            plugin_specs = self.window.core.agents.tools.get_plugin_specs(context, extra, force=True)
-            retriever_tool = self.window.core.agents.tools.get_retriever_tool(context, extra)
+            tools = agent_tools.prepare(context, extra, force=True)
+            function_tools = agent_tools.get_function_tools(ctx, extra, force=True)
+            plugin_tools = agent_tools.get_plugin_tools(context, extra, force=True)
+            plugin_specs = agent_tools.get_plugin_specs(context, extra, force=True)
+            retriever_tool = agent_tools.get_retriever_tool(context, extra)
 
             # disable tools if cmd is not enabled
             if not is_cmd:
@@ -117,6 +123,25 @@ class Runner:
                 plugin_tools = []
                 plugin_specs = []
                 tools = []
+
+            # --- ADDITIONAL CONTEXT ---
+            # append additional context from RAG if available
+            if vector_store_idx and self.window.core.config.get("agent.idx.auto_retrieve", True):
+                ad_context = self.window.core.idx.chat.query_retrieval(
+                    query=prompt,
+                    idx=vector_store_idx,
+                    model=context.model,
+                )
+                if ad_context:
+                    to_append = ""
+                    if ctx.hidden_input is None:
+                        ctx.hidden_input = ""
+                    if not ctx.hidden_input:  # may be not empty (appended before from attachments)
+                        to_append = self.ADDITIONAL_CONTEXT_PREFIX
+                        ctx.hidden_input += to_append
+                    to_append += "\n" + ad_context
+                    ctx.hidden_input += to_append
+                    prompt += "\n\n" + to_append
             
             # append system prompt
             if agent_id in self.APPEND_SYSTEM_PROMPT_TO_MSG:
@@ -145,14 +170,11 @@ class Runner:
                 "preset": context.preset if context else None,
             }
 
-            if self.window.core.agents.provider.has(agent_id):
-                provider = self.window.core.agents.provider.get(agent_id)
-                agent = provider.get_agent(self.window, agent_kwargs)
-                agent_run = provider.run
-                if verbose:
-                    print("Using Agent: " + str(agent_id) + ", model: " + str(model.id))
-            else:
-                raise Exception("Agent not found: " + str(agent_id))
+            provider = self.window.core.agents.provider.get(agent_id)
+            agent = provider.get_agent(self.window, agent_kwargs)
+            agent_run = provider.run
+            if verbose:
+                print(f"Using Agent: {agent_id}, model: {model.id}")
 
             # run agent
             mode = provider.get_mode()
@@ -181,8 +203,7 @@ class Runner:
                 return asyncio.run(self.openai_workflow.run(**kwargs))
 
         except Exception as e:
-            print("Error in agent runner:", e)
-            self.window.core.debug.error(e)
+            self.window.core.debug.log(e)
             self.last_error = e
             return False
 
@@ -204,9 +225,13 @@ class Runner:
             return True  # abort if stopped
 
         agent_id = extra.get("agent_provider", "openai")
-        verbose = self.window.core.config.get("agent.llama.verbose", False)
+        verbose = self.is_verbose()
 
         try:
+            # first, check if agent exists
+            if not self.window.core.agents.provider.has(agent_id):
+                raise Exception(f"Agent not found: {agent_id}")
+
             # prepare input ctx
             ctx = context.ctx
             ctx.extra["agent_input"] = True  # mark as user input
@@ -218,29 +243,29 @@ class Runner:
             model = context.model
             vector_store_idx = extra.get("agent_idx", None)
             system_prompt = context.system_prompt
+            is_expert_call = context.is_expert_call
             max_steps = self.window.core.config.get("agent.llama.steps", 10)
             is_cmd = self.window.core.command.is_cmd(inline=False)
             llm = self.window.core.idx.llm.get(model, stream=False)
             workdir = self.window.core.config.get_workdir_prefix()
 
             # tools
-            self.window.core.agents.tools.context = context
-            self.window.core.agents.tools.agent_idx = vector_store_idx
+            agent_tools = self.window.core.agents.tools
+            agent_tools.set_context(context)
+            agent_tools.set_idx(vector_store_idx)
 
             if "agent_tools" in extra:
                 tools = extra["agent_tools"]  # use tools from extra if provided
             else:
-                tools = self.window.core.agents.tools.prepare(context, extra, force=True)
+                tools = agent_tools.prepare(context, extra, force=True)
+                if not is_cmd:
+                    tools = []  # disable tools if cmd is not enabled, force agent tools
 
             if "agent_history" in extra:
                 history = extra["agent_history"]
             else:
                 history = self.window.core.agents.memory.prepare(context)
 
-            # disable tools if cmd is not enabled
-            if not is_cmd:
-                tools = []
-
             # append system prompt
             if agent_id in self.APPEND_SYSTEM_PROMPT_TO_MSG:
                 if system_prompt:
@@ -264,13 +289,10 @@ class Runner:
                 "preset": context.preset if context else None,
             }
 
-            if self.window.core.agents.provider.has(agent_id):
-                provider = self.window.core.agents.provider.get(agent_id)
-                agent = provider.get_agent(self.window, agent_kwargs)
-                if verbose:
-                    print("Using Agent: " + str(agent_id) + ", model: " + str(model.id))
-            else:
-                raise Exception("Agent not found: " + str(agent_id))
+            provider = self.window.core.agents.provider.get(agent_id)
+            agent = provider.get_agent(self.window, agent_kwargs)
+            if verbose:
+                print(f"Using Agent: {agent_id}, model: {model.id}")
 
             # run agent and return result
             mode = provider.get_mode()
@@ -282,15 +304,23 @@ class Runner:
                 "verbose": verbose,
                 "history": history,
                 "llm": llm,
+                "is_expert_call": is_expert_call,
             }
             # TODO: add support for other modes
             if mode == AGENT_MODE_WORKFLOW:
-                return asyncio.run(self.llama_workflow.run_once(**kwargs))
+                return asyncio.run(self.llama_workflow.run_once(**kwargs))  # return CtxItem
 
         except Exception as e:
-            self.window.core.debug.error(e)
+            self.window.core.debug.log(e)
             self.last_error = e
-            return None
+
+    def is_verbose(self) -> bool:
+        """
+        Check if verbose mode is enabled
+
+        :return: True if verbose mode is enabled
+        """
+        return self.window.core.config.get("agent.llama.verbose", False)
 
     def get_error(self) -> Optional[Exception]:
         """
