@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.30 00:00:00                  #
+# Updated Date: 2025.08.21 07:00:00                  #
 # ================================================== #
 
 import json
@@ -21,10 +21,16 @@ from llama_index.core.tools import BaseTool, FunctionTool, QueryEngineTool, Tool
 
 from pygpt_net.core.bridge.context import BridgeContext
 from pygpt_net.core.events import Event
+from pygpt_net.core.types import (
+    TOOL_QUERY_ENGINE_NAME,
+    TOOL_QUERY_ENGINE_DESCRIPTION,
+    TOOL_QUERY_ENGINE_SPEC,
+)
 from pygpt_net.item.ctx import CtxItem
 
 
 class Tools:
+
     def __init__(self, window=None):
         """
         Agent tools
@@ -62,40 +68,98 @@ class Tools:
         plugin_functions = self.get_plugin_functions(context.ctx, verbose=verbose, force=force)
         tools.extend(plugin_functions)
 
+        # add query engine tool if idx is provided
+        query_engine_tools = self.get_retriever_tool(
+            context=context,
+            extra=extra,
+            verbose=verbose,
+        )
+        if query_engine_tools:
+            tools.extend(query_engine_tools)
+        return tools
+
+    def get_retriever_tool(
+            self,
+            context: BridgeContext,
+            extra: Dict[str, Any],
+            verbose: bool = False
+    ) -> List[BaseTool]:
+        """
+        Prepare tools for agent
+
+        :param context: BridgeContext
+        :param extra: extra data
+        :param verbose: verbose mode
+        :return: list of tools
+        """
+        tool = None
+
         # add query engine tool if idx is provided
         idx = extra.get("agent_idx", None)
-        if idx is not None and idx != "_":
+        if self.window.core.idx.is_valid(idx):
             llm, embed_model = self.window.core.idx.llm.get_service_context(model=context.model)
             index = self.window.core.idx.storage.get(idx, llm, embed_model)  # get index
             if index is not None:
                 query_engine = index.as_query_engine(similarity_top_k=3)
-                query_engine_tools = [
+                tool = [
                     QueryEngineTool(
                         query_engine=query_engine,
                         metadata=ToolMetadata(
-                            name="query_engine",
-                            description=(
-                                "Provides additional context and access to the indexed documents."
-                            ),
+                            name=TOOL_QUERY_ENGINE_NAME,
+                            description=TOOL_QUERY_ENGINE_DESCRIPTION,
                         ),
                     ),
                 ]
-                tools.extend(query_engine_tools)
-        return tools
+        return tool
+
+    def get_openai_retriever_tool(
+            self,
+            idx: str,
+            verbose: bool = False
+    ) -> OpenAIFunctionTool:
+        """
+        Prepare OpenAI retriever tool for agent
+
+        :param idx: index name
+        :param verbose: verbose mode
+        :return: OpenAIFunctionTool instance
+        """
+        async def run_function(run_ctx: RunContextWrapper[Any], args: str) -> str:
+            name = run_ctx.tool_name
+            print(f"[Plugin] Tool call: {name} with args: {args}")
+            cmd = {
+                "cmd": name,
+                "params": json.loads(args)  # args should be a JSON string
+            }
+            return self.tool_exec(name, cmd["params"])
+
+        schema = {"type": "object", "properties": {
+            "query": {
+                "type": "string",
+                "description": "The query string to search in the index."
+            }
+        }, "additionalProperties": False}
+        description = TOOL_QUERY_ENGINE_DESCRIPTION + f" Index: {idx}"
+        return OpenAIFunctionTool(
+            name=TOOL_QUERY_ENGINE_NAME,
+            description=description,
+            params_json_schema=schema,
+            on_invoke_tool=run_function,
+        )
 
     def get_plugin_functions(
             self,
             ctx: CtxItem,
             verbose: bool = False,
             force: bool = False
-    ) -> list:
+    ) -> List[BaseTool]:
         """
         Parse plugin functions
 
         :param ctx: CtxItem
         :param verbose: verbose mode
         :param force: force to get functions even if not needed
-        :return: List of functions
+        :return: List of BaseTool instances
         """
         tools = []
         functions = self.window.core.command.get_functions(force=force)
@@ -110,7 +174,7 @@ class Tools:
 
                 def make_func(name, description):
                     def func(**kwargs):
-                        self.log("[Plugin] Tool call: " + name + " " + str(kwargs))
+                        self.log(f"[Plugin] Tool call: {name} {kwargs}")
                         cmd = {
                             "cmd": name,
                             "params": kwargs,
@@ -137,7 +201,7 @@ class Tools:
                 )
                 tools.append(tool)
             except Exception as e:
-                print(e)
+                self.window.core.debug.log(e)
         return tools
 
     def get_function_tools(
@@ -145,7 +209,7 @@ class Tools:
             ctx: CtxItem,
             verbose: bool = False,
             force: bool = False
-    ) -> list:
+    ) -> List[OpenAIFunctionTool]:
         """
         Parse plugin functions and return as OpenAI FunctionTool instances
 
@@ -166,7 +230,7 @@ class Tools:
 
                 async def run_function(run_ctx: RunContextWrapper[Any], args: str) -> str:
                     name = run_ctx.tool_name
-                    print("[Plugin] Tool call: " + name + " with args: " + str(args))
+                    print(f"[Plugin] Tool call: {name} with args: {args}")
                     cmd = {
                         "cmd": name,
                         "params": json.loads(args)  # args should be a JSON string
@@ -203,7 +267,12 @@ class Tools:
                 )
                 tools.append(tool)
             except Exception as e:
-                print(e)
+                self.window.core.debug.log(e)
+
+        # append query engine tool if idx is provided
+        if self.window.core.idx.is_valid(self.agent_idx):
+            tools.append(self.get_openai_retriever_tool(self.agent_idx))
+
         return tools
 
     def get_plugin_tools(
@@ -212,7 +281,7 @@ class Tools:
             extra: Dict[str, Any],
             verbose: bool = False,
             force: bool = False
-    ) -> dict:
+    ) -> Dict[str, BaseTool]:
         """
         Parse plugin functions
 
@@ -220,6 +289,7 @@ class Tools:
         :param extra: extra data
         :param verbose: verbose mode
         :param force: force to get functions even if not needed
+        :return: Dictionary of tool names and BaseTool instances
         """
         tools = {}
         functions = self.window.core.command.get_functions(force=force)
@@ -230,11 +300,10 @@ class Tools:
                     continue  # skip blacklisted commands
 
                 description = item['desc']
-                schema = json.loads(item['params'])  # from JSON to dict
 
                 def make_func(name, description):
                     def func(**kwargs):
-                        self.log("[Plugin] Tool call: " + name + " " + str(kwargs))
+                        self.log(f"[Plugin] Tool call: {name} {kwargs}")
                         cmd = {
                             "cmd": name,
                             "params": kwargs,
@@ -252,12 +321,20 @@ class Tools:
                 func = make_func(name, description)
                 tools[name] = func
             except Exception as e:
-                print(e)
+                self.window.core.debug.log(e)
 
         # add query engine tool if idx is provided
-        if self.agent_idx is not None and self.agent_idx  != "_":
-            tools["query_engine"] = None  # placeholder for query engine tool
-
+        if self.window.core.idx.is_valid(self.agent_idx):
+            extra = {
+                "agent_idx": self.agent_idx,  # agent index for query engine tool
+            }
+            query_engine_tools = self.get_retriever_tool(
+                context=context,
+                extra=extra,
+                verbose=verbose,
+            )
+            if query_engine_tools:
+                tools["query_engine"] = query_engine_tools[0]  # add query engine tool
         return tools
 
 
@@ -267,7 +344,7 @@ class Tools:
             extra: Dict[str, Any],
             verbose: bool = False,
             force: bool = False
-    ) -> list:
+    ) -> List[str]:
         """
         Parse plugin functions
 
@@ -275,15 +352,14 @@ class Tools:
         :param extra: extra data
         :param verbose: verbose mode
         :param force: force to get functions even if not needed
+        :return: List of tool specifications as strings
         """
         specs = []
         functions = self.window.core.command.get_functions(force=force)
 
         # add query engine tool spec if idx is provided
-        if self.agent_idx is not None and self.agent_idx  != "_":
-            specs.append("**query_engine**: "
-                         "Provides additional context and access to the indexed documents, "
-                         "available params: {'query': {'type': 'string', 'description': 'query string'}}, required: [query]")
+        if self.window.core.idx.is_valid(self.agent_idx):
+            specs.append(TOOL_QUERY_ENGINE_SPEC)
 
         for func in functions:
             try:
@@ -292,10 +368,11 @@ class Tools:
                     continue  # skip blacklisted commands
                 description = func['desc']
                 schema = json.loads(func['params'])  # from JSON to dict
-                spec = "**{}**: {}, available params: {}, required: {}\n".format(name, description, schema.get("properties", {}), schema.get("required", []))
-                specs.append(spec)
+                specs.append(
+                    f"**{name}**: {description}, available params: {schema.get('properties', {})}, required: {schema.get('required', [])}\n"
+                )
             except Exception as e:
-                print(e)
+                self.window.core.debug.log(e)
         return specs
 
     def tool_exec(self, cmd: str, params: Dict[str, Any]) -> str:
@@ -306,22 +383,23 @@ class Tools:
         :param params: command parameters
         :return: command output
         """
-        print("[Plugin] Tool call: " + cmd + " " + str(params))
+        print(f"[Plugin] Tool call: {cmd}, {params}")
+
         # special case for query engine tool
-        if cmd == "query_engine":
+        if cmd == TOOL_QUERY_ENGINE_NAME:
             if "query" not in params:
                 return "Query parameter is required for query_engine tool."
             if self.context is None:
                 return "Context is not set for query_engine tool."
-            if self.agent_idx is None or self.agent_idx == "_":
+            if not self.window.core.idx.is_valid(self.agent_idx):
                 return "Agent index is not set for query_engine tool."
             llm, embed_model = self.window.core.idx.llm.get_service_context(model=self.context.model)
             index = self.window.core.idx.storage.get(self.agent_idx, llm, embed_model)  # get index
             if index is not None:
                 query_engine = index.as_query_engine(similarity_top_k=3)
                 response = query_engine.query(params["query"])
-                print("[Plugin] Query engine response: " + str(response))
-                self.log("[Plugin] Query engine response: " + str(response))
+                print(f"[Plugin] Query engine response: {response}")
+                self.log(f"[Plugin] Query engine response: {response}")
                 return str(response)
             else:
                 return "Index not found for query_engine tool."
@@ -340,41 +418,6 @@ class Tools:
         )
         return response
 
-    def get_retriever_tool(
-            self,
-            context: BridgeContext,
-            extra: Dict[str, Any],
-            verbose: bool = False
-    ) -> List[BaseTool]:
-        """
-        Prepare tools for agent
-
-        :param context: BridgeContext
-        :param extra: extra data
-        :param verbose: verbose mode
-        :return: list of tools
-        """
-        tool = None
-        # add query engine tool if idx is provided
-        idx = extra.get("agent_idx", None)
-        if idx is not None and idx != "_":
-            llm, embed_model = self.window.core.idx.llm.get_service_context(model=context.model)
-            index = self.window.core.idx.storage.get(idx, llm, embed_model)  # get index
-            if index is not None:
-                query_engine = index.as_query_engine(similarity_top_k=3)
-                tool = [
-                    QueryEngineTool(
-                        query_engine=query_engine,
-                        metadata=ToolMetadata(
-                            name="query_engine",
-                            description=(
-                                "Provides additional context and access to the indexed documents."
-                            ),
-                        ),
-                    ),
-                ]
-        return tool
-
     def export_sources(
             self,
             response: AgentChatResponse
@@ -387,12 +430,13 @@ class Tools:
         """
         data = []
         for output in response.sources:
-            item = {}
-            item["ToolOutput"] = {
-                "content": str(output.content),
-                "tool_name": str(output.tool_name),
-                "raw_input": str(output.raw_input),
-                "raw_output": str(output.raw_output),
+            item = {
+                "ToolOutput": {
+                    "content": str(output.content),
+                    "tool_name": str(output.tool_name),
+                    "raw_input": str(output.raw_input),
+                    "raw_output": str(output.raw_output),
+                }
             }
             data.append(item)
         return data
@@ -458,6 +502,22 @@ class Tools:
             if clear:
                 self.clear_last_tool_output()  # clear after use
 
+    def set_idx(self, agent_idx: str):
+        """
+        Set agent index for query engine tool
+
+        :param agent_idx: agent index
+        """
+        self.agent_idx = agent_idx
+
+    def set_context(self, context: BridgeContext):
+        """
+        Set context for tool execution
+
+        :param context: BridgeContext instance
+        """
+        self.context = context
+
     def log(self, msg: str):
         """
         Log message
