@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.03 14:00:00                  #
+# Updated Date: 2025.08.11 14:00:00                  #
 # ================================================== #
 
 from PySide6.QtCore import QObject, Signal, QRunnable, Slot
@@ -26,10 +26,9 @@ class BridgeSignals(QObject):
     response = Signal(object)  # KernelEvent
 
 
-class BridgeWorker(QObject, QRunnable):
+class BridgeWorker(QRunnable):
     """Bridge worker"""
     def __init__(self, *args, **kwargs):
-        QObject.__init__(self)
         QRunnable.__init__(self)
         self.signals = BridgeSignals()
         self.args = args
@@ -82,6 +81,7 @@ class BridgeWorker(QObject, QRunnable):
                     signals=self.signals,
                 )
                 if result:
+                    self.cleanup()
                     return  # don't emit any signals (handled in agent runner, step by step)
                 else:
                     self.extra["error"] = str(self.window.core.agents.runner.get_error())
@@ -112,6 +112,7 @@ class BridgeWorker(QObject, QRunnable):
                     'extra': self.extra,
                 })
                 self.signals.response.emit(event)
+                self.cleanup()
                 return
 
         # send response to main thread
@@ -123,6 +124,18 @@ class BridgeWorker(QObject, QRunnable):
             })
             self.signals.response.emit(event)
 
+        self.cleanup()
+
+    def cleanup(self):
+        """Cleanup resources after worker execution."""
+        sig = self.signals
+        self.signals = None
+        if sig is not None:
+            try:
+                sig.deleteLater()
+            except RuntimeError:
+                pass
+
     def handle_post_prompt_async(self):
         """Handle post prompt async event"""
         event = Event(Event.POST_PROMPT_ASYNC, {
