@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.15 23:00:00                  #
+# Updated Date: 2025.08.19 07:00:00                  #
 # ================================================== #
 
 import os
@@ -41,17 +41,15 @@ class Body:
                 <script type="text/javascript" src="qrc:///qtwebchannel/qwebchannel.js"></script>
                 <script type="text/javascript" src="qrc:///js/highlight.min.js"></script>
                 <script type="text/javascript" src="qrc:///js/katex.min.js"></script>
-                <script type="text/javascript" src="qrc:///js/auto-render.min.js"></script>
                 <script>
-
+                const DEBUG_MODE = false;
                 let scrollTimeout = null;
                 let prevScroll = 0;
                 let bridge;
+                let streamQ = [];
+                let streamRAF = 0;
                 let pid = """
-    _HTML_P2 = """
-                new QWebChannel(qt.webChannelTransport, function (channel) {
-                    bridge = channel.objects.bridge;
-                });
+    _HTML_P2 = """                
                 let collapsed_idx = [];
                 let domOutputStream = document.getElementById('_append_output_');
                 let domOutput = document.getElementById('_output_');
@@ -69,6 +67,23 @@ class Body:
                 let pendingHighlightMath = false;
                 let scrollScheduled = false;
 
+                // timers
+                let tipsTimers = [];
+
+                // clear previous references
+                function resetEphemeralDomRefs() {
+                    domLastCodeBlock = null;
+                    domLastParagraphBlock = null;
+                }
+                function dropIfDetached() {
+                    if (domLastCodeBlock && !domLastCodeBlock.isConnected) domLastCodeBlock = null;
+                    if (domLastParagraphBlock && !domLastParagraphBlock.isConnected) domLastParagraphBlock = null;
+                }
+                function stopTipsTimers() {
+                    tipsTimers.forEach(clearTimeout);
+                    tipsTimers = [];
+                }
+
                 history.scrollRestoration = "manual";
                 document.addEventListener('keydown', function(event) {
                     if (event.ctrlKey && event.key === 'f') {
@@ -128,13 +143,16 @@ class Body:
                     if (withMath) {
                         renderMath(root);
                     }
+                    if (DEBUG_MODE) log("execute highlight");
                     restoreCollapsedCode(root);
                 }
                 function highlightCode(withMath = true, root = null) {
+                     if (DEBUG_MODE) log("queue highlight, withMath: " + withMath);
                     scheduleHighlight(root || document, withMath);
                 }
                 function hideTips() {
                     if (tips_hidden) return;
+                    stopTipsTimers();
                     const t = els.tips || document.getElementById('tips');
                     if (t) t.style.display = 'none';
                     tips_hidden = true;
@@ -149,24 +167,27 @@ class Body:
                 function cycleTips() {
                     if (tips_hidden) return;
                     if (tips.length === 0) return;
-                    let tipContainer = els.tips || document.getElementById('tips');
                     let currentTip = 0;
                     function showNextTip() {
                         if (tips_hidden) return;
+                        const tipContainer = els.tips || document.getElementById('tips');
+                        if (!tipContainer) return;
                         tipContainer.innerHTML = tips[currentTip];
                         tipContainer.classList.add('visible');
-                        setTimeout(function() {
+                        tipsTimers.push(setTimeout(function() {
                             if (tips_hidden) return;
                             tipContainer.classList.remove('visible');
-                            setTimeout(function(){
+                            tipsTimers.push(setTimeout(function(){
                                 currentTip = (currentTip + 1) % tips.length;
                                 showNextTip();
-                            }, 1000);
-                        }, 10000);
+                            }, 1000));
+                        }, 15000));
                     }
+                    stopTipsTimers();
                     showNextTip();
                 }
                 function renderMath(root) {
+                    if (DEBUG_MODE) log("execute math");
                     const scope = root || document;
                     const scripts = scope.querySelectorAll('script[type^="math/tex"]');
                     scripts.forEach(function(script) {
@@ -212,19 +233,16 @@ class Body:
                     }
                     prevScroll = el.scrollHeight;
                 }
-                function sanitize(content) {
-                    return content.replace(/&amp;lt;/g, '&lt;').replace(/&amp;gt;/g, '&gt;');
-                }
                 function appendToInput(content) {
                     const element = els.appendInput || document.getElementById('_append_input_');
                     if (element) {
-                        element.insertAdjacentHTML('beforeend', sanitize(content));
+                        element.insertAdjacentHTML('beforeend', content);
                         highlightCode(true, element);
                         scheduleScroll();
                     }
                 }
                 function getStreamContainer() {
-                    if (domOutputStream && document.body.contains(domOutputStream)) {
+                    if (domOutputStream && domOutputStream.isConnected) {
                         return domOutputStream;
                     }
                     let element = els.appendOutput || document.getElementById('_append_output_');
@@ -233,46 +251,55 @@ class Body:
                     }
                     return element;
                 }
-                function appendToOutput(bot_name, content) {
-                    hideTips();
-                    const element = getStreamContainer();
-                    if (element) {
-                        let box = element.querySelector('.msg-box');
-                        let msg;
-                        if (!box) {
-                            box = document.createElement('div');
-                            box.classList.add('msg-box');
-                            box.classList.add('msg-bot');
-                            var name = document.createElement('div');
-                            name.classList.add('name-header');
-                            name.classList.add('name-bot');
-                            name.textContent = bot_name;
-                            msg = document.createElement('div');
-                            msg.classList.add('msg');
-                            box.appendChild(name);
-                            box.appendChild(msg);
-                            element.appendChild(box);
-                        } else {
-                            msg = box.querySelector('.msg');
-                        }
-                        if (msg) {
-                            msg.insertAdjacentHTML('beforeend', sanitize(content));
-                            highlightCode(true, msg);
-                            scheduleScroll();
-                        }
-                    }
-                }
                 function appendNode(content) {
+                    if (DEBUG_MODE) {
+                        log("APPEND NODE: {" + content + "}");
+                    }
                     clearStreamBefore();
                     prevScroll = 0;
                     const element = els.nodes || document.getElementById('_nodes_');
                     if (element) {
                         element.classList.remove('empty_list');
-                        element.insertAdjacentHTML('beforeend', sanitize(content));
+                        element.insertAdjacentHTML('beforeend', content);
                         highlightCode(true, element);
-                        scheduleScroll();
+                        scrollToBottom(false);  // without schedule
                     }
                 }
+                function replaceNodes(content) {
+                    if (DEBUG_MODE) {
+                        log("REPLACE NODES: {" + content + "}");
+                    }
+                    clearStreamBefore();
+                    prevScroll = 0;
+                    const element = els.nodes || document.getElementById('_nodes_');
+                    if (element) {
+                        element.classList.remove('empty_list');
+                        element.replaceChildren();
+                        element.insertAdjacentHTML('beforeend', content);
+                        highlightCode(true, element);
+                        scrollToBottom(false);  // without schedule
+                    }
+                }
+                function clean() {
+                    if (DEBUG_MODE) {
+                        log("-- CLEAN DOM --");
+                    }
+                    const el = els.nodes || document.getElementById('_nodes_');
+                    if (el) {
+                        el.replaceChildren();
+                    }
+                    resetEphemeralDomRefs();
+                    els = {};
+                    /*
+                    try {
+                        if (window.gc) {
+                            window.gc();
+                        }
+                    } catch (e) {
+                        // gc not available
+                    }
+                    */
+                }
                 function appendExtra(id, content) {
                     hideTips();
                     prevScroll = 0;
@@ -280,7 +307,7 @@ class Body:
                     if (element) {
                         const extra = element.querySelector('.msg-extra');
                         if (extra) {
-                            extra.insertAdjacentHTML('beforeend', sanitize(content));
+                            extra.insertAdjacentHTML('beforeend', content);
                             highlightCode(true, extra);
                             scheduleScroll();
                         }
@@ -296,6 +323,7 @@ class Body:
                     if (element) {
                         element.remove();
                     }
+                    resetEphemeralDomRefs();
                     highlightCode();
                     scheduleScroll();
                 }
@@ -306,19 +334,23 @@ class Body:
                         const elements = container.querySelectorAll('.msg-box');
                         let remove = false;
                         elements.forEach(function(element) {
-                            if (element.id.endsWith('-' + id)) {
+                            if (element.id && element.id.endsWith('-' + id)) {
                                 remove = true;
                             }
                             if (remove) {
                                 element.remove();
                             }
                         });
+                        resetEphemeralDomRefs();
                         highlightCode(true, container);
                         scheduleScroll();
                     }
                 }
                 function clearStream() {
                     hideTips();
+                    if (DEBUG_MODE) {
+                        log("STREAM CLEAR");
+                    }
                     domLastParagraphBlock = null;
                     domLastCodeBlock = null;
                     domOutputStream = null;
@@ -344,17 +376,38 @@ class Body:
                 }
                 function beginStream() {
                     hideTips();
+                    if (DEBUG_MODE) {
+                        log("STREAM BEGIN");
+                    }
                     clearOutput();
                     scheduleScroll();
                 }
                 function endStream() {
+                    if (DEBUG_MODE) {
+                        log("STREAM END");
+                    }
                     clearOutput();
                 }
+                function enqueueStream(name_header, content, chunk, replace = false, is_code_block = false) {
+                  streamQ.push({name_header, content, chunk, replace, is_code_block});
+                  if (!streamRAF) {
+                    streamRAF = requestAnimationFrame(drainStream);
+                  }
+                }                
+                function drainStream() {
+                  streamRAF = 0;
+                  while (streamQ.length) {
+                    const {name_header, content, chunk, replace, is_code_block} = streamQ.shift();
+                    appendStream(name_header, content, chunk, replace, is_code_block);
+                  }
+                }
                 function appendStream(name_header, content, chunk, replace = false, is_code_block = false) {
+                    dropIfDetached(); // clear references to detached elements
                     hideTips();
+                    if (DEBUG_MODE) {
+                        log("APPEND CHUNK: {" + chunk + "}, CONTENT: {"+content+"}, replace: " + replace + ", is_code_block: " + is_code_block);
+                    }
                     const element = getStreamContainer();
-                    let doHighlight = true;
-                    let doMath = true;
                     let msg;
                     if (element) {
                         let box = element.querySelector('.msg-box');
@@ -378,7 +431,15 @@ class Body:
                         }
                         if (msg) {
                             if (replace) {
-                                msg.innerHTML = sanitize(content);
+                                msg.replaceChildren();
+                                if (content) {
+                                  msg.insertAdjacentHTML('afterbegin', content);
+                                }
+                                let doMath = true;
+                                if (is_code_block) {
+                                    doMath = false;
+                                }
+                                highlightCode(doMath, msg);
                                 domLastCodeBlock = null;
                                 domLastParagraphBlock = null;
                             } else {
@@ -395,78 +456,31 @@ class Body:
                                     if (lastCodeBlock) {
                                         lastCodeBlock.insertAdjacentHTML('beforeend', chunk);
                                         domLastCodeBlock = lastCodeBlock;
-                                        doHighlight = false;
                                     } else {
                                         msg.insertAdjacentHTML('beforeend', chunk);
                                         domLastCodeBlock = null;
                                     }
-                                    doMath = false;
                                 } else {
                                     domLastCodeBlock = null;
-                                    if (msg.innerHTML.trim().endsWith('</p>')) {
-                                        let lastParagraphBlock;
-                                        if (domLastParagraphBlock) {
-                                            lastParagraphBlock = domLastParagraphBlock;
-                                        } else {
-                                            const blocksParagraph = msg.querySelectorAll('p');
-                                            if (blocksParagraph.length > 0) {
-                                                lastParagraphBlock = blocksParagraph[blocksParagraph.length - 1];
-                                            }
-                                        }
-                                        if (lastParagraphBlock) {
-                                            domLastParagraphBlock = lastParagraphBlock;
-                                            lastParagraphBlock.insertAdjacentHTML('beforeend', chunk);
-                                        } else {
-                                            domLastParagraphBlock = null;
-                                            msg.insertAdjacentHTML('beforeend', chunk);
-                                        }
+                                    let p = (domLastParagraphBlock && msg.contains(domLastParagraphBlock))
+                                        ? domLastParagraphBlock
+                                        : (msg.lastElementChild && msg.lastElementChild.tagName === 'P'
+                                            ? msg.lastElementChild
+                                            : null);
+                                    if (p) {
+                                        p.insertAdjacentHTML('beforeend', chunk);
+                                        domLastParagraphBlock = p;
                                     } else {
-                                        domLastParagraphBlock = null;
                                         msg.insertAdjacentHTML('beforeend', chunk);
+                                        const last = msg.lastElementChild;
+                                        domLastParagraphBlock = (last && last.tagName === 'P') ? last : null;
                                     }
-                                    doHighlight = false;
                                 }
                             }
                         }
                     }
-                    if (replace) {
-                        if (doHighlight) {
-                            highlightCode(doMath, msg);
-                        }
-                    }
                     scheduleScroll(true);
                 }
-                function replaceOutput(name_header, content) {
-                    hideTips();
-                    const element = getStreamContainer();
-                    if (element) {
-                        let box = element.querySelector('.msg-box');
-                        let msg;
-                        if (!box) {
-                            box = document.createElement('div');
-                            box.classList.add('msg-box');
-                            box.classList.add('msg-bot');
-                            if (name_header != '') {
-                                const name = document.createElement('div');
-                                name.classList.add('name-header');
-                                name.classList.add('name-bot');
-                                name.innerHTML = name_header;
-                                box.appendChild(name);
-                            }
-                            msg = document.createElement('div');
-                            msg.classList.add('msg');
-                            box.appendChild(msg);
-                            element.appendChild(box);
-                        } else {
-                            msg = box.querySelector('.msg');
-                        }
-                        if (msg) {
-                            msg.innerHTML = sanitize(content);
-                            highlightCode(true, msg);
-                            scheduleScroll();
-                        }
-                    }
-                }
                 function nextStream() {
                     hideTips();
                     const element = els.appendOutput || document.getElementById('_append_output_');
@@ -497,7 +511,7 @@ class Body:
                         const last = elements[elements.length - 1];
                         const contentEl = last.querySelector('.content');
                         if (contentEl) {
-                            contentEl.insertAdjacentHTML('beforeend', sanitize(content));
+                            contentEl.insertAdjacentHTML('beforeend', content);
                         }
                     }
                 }
@@ -509,7 +523,7 @@ class Body:
                         const last = elements[elements.length - 1];
                         const contentEl = last.querySelector('.content');
                         if (contentEl) {
-                            contentEl.innerHTML = sanitize(content);
+                            contentEl.innerHTML = content;
                         }
                     }
                 }
@@ -584,7 +598,7 @@ class Body:
                             element.classList.remove('hidden');
                             element.classList.add('visible');
                         }
-                        element.innerHTML = sanitize(content);
+                        element.innerHTML = content;
                         highlightCode(true, element);
                         scheduleScroll();
                     }
@@ -603,6 +617,7 @@ class Body:
                         element.replaceChildren();
                         element.classList.add('empty_list');
                     }
+                    resetEphemeralDomRefs();
                 }
                 function clearInput() {
                     const element = els.appendInput || document.getElementById('_append_input_');
@@ -627,9 +642,11 @@ class Body:
                             element.classList.add('hidden');
                             setTimeout(function() {
                                 element.replaceChildren();
+                                resetEphemeralDomRefs();
                             }, 1000);
                         } else {
                             element.replaceChildren();
+                            resetEphemeralDomRefs();
                         }
                     }
                 }
@@ -756,6 +773,13 @@ class Body:
                     }
                 }
                 document.addEventListener('DOMContentLoaded', function() {
+                    new QWebChannel(qt.webChannelTransport, function (channel) {
+                        bridge = channel.objects.bridge;
+                        bridge.chunk.connect((name, html, chunk, replace, isCode) => {
+                            appendStream(name, html, chunk, replace, isCode);
+                        });
+                        if (bridge.js_ready) bridge.js_ready();
+                    });
                     initDomRefs();
                     const container = els.container;
                     function addClassToMsg(id, className) {
@@ -857,7 +881,7 @@ class Body:
                         }
                     });
                 });
-                setTimeout(cycleTips, 20000);
+                setTimeout(cycleTips, 60000);  // after 60 seconds
                 </script>
             </head>
             <body """
@@ -973,9 +997,9 @@ class Body:
         syntax_style = self.window.core.config.get("render.code_syntax") or "default"
 
         theme_css = self.window.controller.theme.markdown.get_web_css().replace('%fonts%', fonts_path)
-        parts = [self._SPINNER, theme_css]
-        parts.append("pre { color: #fff; }" if syntax_style in self._syntax_dark else "pre { color: #000; }")
-        parts.append(self.highlight.get_style_defs())
+        parts = [self._SPINNER, theme_css,
+                 "pre { color: #fff; }" if syntax_style in self._syntax_dark else "pre { color: #000; }",
+                 self.highlight.get_style_defs()]
         return "\n".join(parts)
 
     def prepare_action_icons(self, ctx: CtxItem) -> str:
@@ -1002,32 +1026,19 @@ class Body:
         if ctx.output:
             cid = ctx.id
             t = trans
-
             icons.append(
-                f'<a href="extra-audio-read:{cid}" class="action-icon" data-id="{cid}" role="button">'
-                f'<span class="cmd">{self.get_icon("volume", t("ctx.extra.audio"), ctx)}</span></a>'
-            )
+                f'<a href="extra-audio-read:{cid}" class="action-icon" data-id="{cid}" role="button"><span class="cmd">{self.get_icon("volume", t("ctx.extra.audio"), ctx)}</span></a>')
             icons.append(
-                f'<a href="extra-copy:{cid}" class="action-icon" data-id="{cid}" role="button">'
-                f'<span class="cmd">{self.get_icon("copy", t("ctx.extra.copy"), ctx)}</span></a>'
-            )
+                f'<a href="extra-copy:{cid}" class="action-icon" data-id="{cid}" role="button"><span class="cmd">{self.get_icon("copy", t("ctx.extra.copy"), ctx)}</span></a>')
             icons.append(
-                f'<a href="extra-replay:{cid}" class="action-icon" data-id="{cid}" role="button">'
-                f'<span class="cmd">{self.get_icon("reload", t("ctx.extra.reply"), ctx)}</span></a>'
-            )
+                f'<a href="extra-replay:{cid}" class="action-icon" data-id="{cid}" role="button"><span class="cmd">{self.get_icon("reload", t("ctx.extra.reply"), ctx)}</span></a>')
             icons.append(
-                f'<a href="extra-edit:{cid}" class="action-icon edit-icon" data-id="{cid}" role="button">'
-                f'<span class="cmd">{self.get_icon("edit", t("ctx.extra.edit"), ctx)}</span></a>'
-            )
+                f'<a href="extra-edit:{cid}" class="action-icon edit-icon" data-id="{cid}" role="button"><span class="cmd">{self.get_icon("edit", t("ctx.extra.edit"), ctx)}</span></a>')
             icons.append(
-                f'<a href="extra-delete:{cid}" class="action-icon edit-icon" data-id="{cid}" role="button">'
-                f'<span class="cmd">{self.get_icon("delete", t("ctx.extra.delete"), ctx)}</span></a>'
-            )
+                f'<a href="extra-delete:{cid}" class="action-icon edit-icon" data-id="{cid}" role="button"><span class="cmd">{self.get_icon("delete", t("ctx.extra.delete"), ctx)}</span></a>')
             if not self.window.core.ctx.is_first_item(cid):
                 icons.append(
-                    f'<a href="extra-join:{cid}" class="action-icon edit-icon" data-id="{cid}" role="button">'
-                    f'<span class="cmd">{self.get_icon("playlist_add", t("ctx.extra.join"), ctx)}</span></a>'
-                )
+                    f'<a href="extra-join:{cid}" class="action-icon edit-icon" data-id="{cid}" role="button"><span class="cmd">{self.get_icon("playlist_add", t("ctx.extra.join"), ctx)}</span></a>')
         return icons
 
     def get_icon(
@@ -1046,9 +1057,7 @@ class Body:
         """
         app_path = self.window.core.config.get_app_path()
         icon_path = os.path.join(app_path, "data", "icons", f"{icon}.svg")
-        return (
-            f'<img src="file://{icon_path}" class="action-img" title="{title}" alt="{title}" data-id="{item.id}">'
-        )
+        return f'<img src="file://{icon_path}" class="action-img" title="{title}" alt="{title}" data-id="{item.id}">'
 
     def get_image_html(
             self,
@@ -1066,14 +1075,7 @@ class Body:
         """
         url, path = self.window.core.filesystem.extract_local_url(url)
         basename = os.path.basename(path)
-        return (
-            f'<div class="extra-src-img-box" title="{url}">'
-            f'<div class="img-outer"><div class="img-wrapper">'
-            f'<a href="{url}"><img src="{path}" class="image"></a>'
-            f'</div>'
-            f'<a href="{url}" class="title">{basename}</a>'
-            f'</div></div>'
-        )
+        return f'<div class="extra-src-img-box" title="{url}"><div class="img-outer"><div class="img-wrapper"><a href="{url}"><img src="{path}" class="image"></a></div><a href="{url}" class="title">{basename}</a></div></div><br/>'
 
     def get_url_html(
             self,
