@@ -6,13 +6,14 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.15 23:00:00                  #
+# Updated Date: 2025.08.19 07:00:00                  #
 # ================================================== #
 
 import copy
 import datetime
 import json
 import time
+from typing import Optional
 
 
 class CtxItem:
@@ -94,7 +95,7 @@ class CtxItem:
 
 
     @property
-    def final_input(self) -> str:
+    def final_input(self) -> Optional[str]:
         """
         Final input
 
@@ -103,11 +104,11 @@ class CtxItem:
         if self.input is None:
             return None
         if self.hidden_input:
-            return self.input + "\n\n" + self.hidden_input
+            return "\n\n".join([self.input, self.hidden_input])
         return self.input
 
     @property
-    def final_output(self) -> str:
+    def final_output(self) -> Optional[str]:
         """
         Final output
 
@@ -116,7 +117,7 @@ class CtxItem:
         if self.output is None:
             return None
         if self.hidden_output:
-            return self.output + "\n\n" + self.hidden_output
+            return "\n\n".join([self.output, self.hidden_output])
         return self.output
 
     def clear_reply(self):
