@@ -11,6 +11,7 @@
 
 from PySide6.QtWidgets import QVBoxLayout, QLabel, QHBoxLayout, QWidget, QCheckBox
 
+from pygpt_net.ui.widget.option.combo import OptionCombo
 from pygpt_net.ui.widget.option.slider import OptionSlider
 from pygpt_net.ui.widget.option.toggle_label import ToggleLabel
 from pygpt_net.utils import trans
@@ -42,9 +43,20 @@ class AgentLlama:
                 option,
             )
         self.window.ui.nodes['agent.llama.loop.score'].setToolTip(trans("toolbox.agent.llama.loop.score.tooltip"))
-
         self.window.ui.config['global']['agent.llama.loop.score'] = self.window.ui.nodes['agent.llama.loop.score']
 
+        option_mode = self.window.controller.agent.llama.options["agent.llama.loop.mode"]
+        self.window.ui.nodes['agent.llama.loop.mode.label'] = QLabel(trans("toolbox.agent.llama.loop.mode.label"))
+        self.window.ui.nodes['agent.llama.loop.mode'] = \
+            OptionCombo(
+                self.window,
+                'global',
+                'agent.llama.loop.mode',
+                option_mode,
+            )
+        self.window.ui.nodes['agent.llama.loop.mode'].setToolTip(trans("toolbox.agent.llama.loop.mode.tooltip"))
+        self.window.ui.config['global']['agent.llama.loop.mode'] = self.window.ui.nodes['agent.llama.loop.mode']
+
         # loop enabled
         self.window.ui.nodes['agent.llama.loop.enabled'] = ToggleLabel(trans("toolbox.agent.llama.loop.enabled.label"), parent=self.window)
         self.window.ui.nodes['agent.llama.loop.enabled'].box.stateChanged.connect(
@@ -66,6 +78,7 @@ class AgentLlama:
         rows = QVBoxLayout()
         rows.addWidget(self.window.ui.nodes['agent.llama.loop.label'])
         rows.addLayout(cols)
+        rows.addWidget(self.window.ui.nodes['agent.llama.loop.mode'])
 
         self.window.ui.nodes['agent_llama.options'] = QWidget()
         self.window.ui.nodes['agent_llama.options'].setLayout(rows)
