@@ -118,8 +118,6 @@ class Presets:
             self.window.ui.models[self.id] = model
             view.setModel(model)
 
-        blocker = QtCore.QSignalBlocker(model)
-
         rc = model.rowCount()
         if rc:
             model.removeRows(0, rc)
@@ -144,6 +142,4 @@ class Presets:
                 model.setData(index, name, QtCore.Qt.DisplayRole)
                 model.setData(index, tooltip, QtCore.Qt.ToolTipRole)
 
-        del blocker
-
         view.restore_selection()
\ No newline at end of file
