@@ -6,12 +6,12 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.16 00:00:00                  #
+# Updated Date: 2025.08.20 20:00:00                  #
 # ================================================== #
 
 import os
 
-from PySide6.QtCore import QTimer, Signal, Slot, QThreadPool, QEvent, Qt, QLoggingCategory
+from PySide6.QtCore import QTimer, Signal, Slot, QThreadPool, QEvent, Qt, QLoggingCategory, QEventLoop
 from PySide6.QtGui import QShortcut, QKeySequence
 from qasync import QApplication
 from PySide6.QtWidgets import QMainWindow
@@ -22,6 +22,7 @@ from pygpt_net.container import Container
 from pygpt_net.controller import Controller
 from pygpt_net.tools import Tools
 from pygpt_net.ui import UI
+from pygpt_net.ui.widget.textarea.web import ChatWebOutput
 from pygpt_net.utils import get_app_meta
 
 
@@ -114,7 +115,10 @@ class MainWindow(QMainWindow, QtStyleTools):
         if not render_debug:
             QLoggingCategory.setFilterRules("*.info=false")
         else:
-            os.environ["QTWEBENGINE_CHROMIUM_FLAGS"] = "--enable-logging --log-level=0"
+            if "QTWEBENGINE_CHROMIUM_FLAGS" in os.environ:
+                os.environ["QTWEBENGINE_CHROMIUM_FLAGS"] += " --enable-logging --log-level=0"
+            else:
+                os.environ["QTWEBENGINE_CHROMIUM_FLAGS"] = "--enable-logging --log-level=0"
 
         # OpenGL disable
         if self.core.config.get("render.open_gl") is False:
@@ -221,6 +225,10 @@ class MainWindow(QMainWindow, QtStyleTools):
         self.ui.post_setup()
         self.tools.post_setup()
 
+    def showEvent(self, e):
+        super().showEvent(e)
+        QTimer.singleShot(0, self.ui.on_show)
+
     def update(self):
         """Called on every update (real-time)"""
         self.controller.on_update()
@@ -246,7 +254,9 @@ class MainWindow(QMainWindow, QtStyleTools):
 
         :param message: status message
         """
-        self.dispatch(KernelEvent(KernelEvent.STATUS, {"status": str(message)}))
+        message = message if isinstance(message, str) else str(message)
+        self.dispatch(KernelEvent(KernelEvent.STATUS, {"status": message}))
+        del message  # free memory
 
     @Slot(str)
     def update_state(self, state: str):
@@ -260,7 +270,7 @@ class MainWindow(QMainWindow, QtStyleTools):
         self.state = state
         self.ui.tray.set_icon(state)
 
-    @Slot(object)
+    @Slot(object, bool)
     def dispatch(self, event: BaseEvent, all: bool = False):
         """
         Dispatch App event
@@ -280,6 +290,17 @@ class MainWindow(QMainWindow, QtStyleTools):
             event.ignore()
             self.hide()
             return
+
+        for view in self.findChildren(ChatWebOutput):
+            try:
+                view.on_delete()
+            except Exception:
+                pass
+
+        for _ in range(6):
+            QApplication.sendPostedEvents(None, QEvent.DeferredDelete)
+            QApplication.processEvents(QEventLoop.AllEvents, 50)
+
         self.shutdown()
         event.accept()
 
