@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.11.17 03:00:00                  #
+# Updated Date: 2025.08.16 00:00:00                  #
 # ================================================== #
 
 from PySide6.QtGui import QAction, QIcon
@@ -35,10 +35,7 @@ class Tray:
         """
         if not self.is_tray:
             return
-
-        self.icon.setIcon(
-            self.window.ui.get_tray_icon(state)
-        )
+        self.icon.setIcon(self.window.ui.get_tray_icon(state))
 
     def show_msg(self, title: str, msg: str, icon: str = 'Information'):
         """
@@ -50,11 +47,10 @@ class Tray:
         """
         if not self.is_tray:
             return
-
         self.icon.showMessage(
-            "PyGPT: " + title,
+            f"PyGPT: {title}",
             msg,
-            getattr(QSystemTrayIcon, icon),
+            getattr(QSystemTrayIcon, icon, QSystemTrayIcon.Information),
         )
 
     def setup(self, app=None):
@@ -65,73 +61,68 @@ class Tray:
         """
         if not self.window.core.config.get('layout.tray'):
             return
+        if self.is_tray and self.icon is not None:
+            return
 
         self.is_tray = True
+        w = self.window
+        ui = w.ui
+        tray_menu = ui.tray_menu
 
         self.icon = QSystemTrayIcon(
-            self.window.ui.get_tray_icon(self.window.STATE_IDLE),
+            ui.get_tray_icon(w.STATE_IDLE),
             app,
         )
-        self.icon.setToolTip("PyGPT {} ({})".format(
-            self.window.meta['version'],
-            self.window.meta['build'].replace('.', '-')),
-        )
+        self.icon.setToolTip(f"PyGPT {w.meta['version']} ({w.meta['build'].replace('.', '-')})")
 
-        # restore
-        action = QAction(trans("action.open"), self.window)
+        action = QAction(trans("action.open"), w)
         action.setIcon(QIcon(":/icons/apps.svg"))
-        self.window.ui.tray_menu['restore'] = action
-        self.window.ui.tray_menu['restore'].triggered.connect(self.window.restore)
-        self.window.ui.tray_menu['restore'].setVisible(False)
+        tray_menu['restore'] = action
+        tray_menu['restore'].triggered.connect(w.restore)
+        tray_menu['restore'].setVisible(False)
 
-        # new context
-        action = QAction(trans("menu.file.new"), self.window)
+        action = QAction(trans("menu.file.new"), w)
         action.setIcon(QIcon(":/icons/add.svg"))
-        self.window.ui.tray_menu['new'] = action
-        self.window.ui.tray_menu['new'].triggered.connect(self.new_ctx)
+        tray_menu['new'] = action
+        tray_menu['new'].triggered.connect(self.new_ctx)
 
-        # scheduled tasks
-        action = QAction(trans("menu.tray.scheduled"), self.window)
+        action = QAction(trans("menu.tray.scheduled"), w)
         action.setIcon(QIcon(":/icons/schedule.svg"))
-        self.window.ui.tray_menu['scheduled'] = action
-        self.window.ui.tray_menu['scheduled'].triggered.connect(self.open_scheduled_tasks)
+        tray_menu['scheduled'] = action
+        tray_menu['scheduled'].triggered.connect(self.open_scheduled_tasks)
 
-        # check for updates
-        action = QAction(trans("menu.info.updates"), self.window)
+        action = QAction(trans("menu.info.updates"), w)
         action.setIcon(QIcon(":/icons/public_filled.svg"))
-        self.window.ui.tray_menu['update'] = action
-        self.window.ui.tray_menu['update'].triggered.connect(self.check_updates)
+        tray_menu['update'] = action
+        tray_menu['update'].triggered.connect(self.check_updates)
 
-        # open notepad
-        action = QAction(trans("menu.tray.notepad"), self.window)
+        action = QAction(trans("menu.tray.notepad"), w)
         action.setIcon(QIcon(":/icons/paste.svg"))
-        self.window.ui.tray_menu['open_notepad'] = action
-        self.window.ui.tray_menu['open_notepad'].triggered.connect(self.open_notepad)
+        tray_menu['open_notepad'] = action
+        tray_menu['open_notepad'].triggered.connect(self.open_notepad)
 
-        if self.window.controller.notepad.get_num_notepads() == 0:
+        if w.controller.notepad.get_num_notepads() == 0:
             self.hide_notepad_menu()
 
-        # ask with screenshot
-        action = QAction(trans("menu.tray.screenshot"), self.window)
+        action = QAction(trans("menu.tray.screenshot"), w)
         action.setIcon(QIcon(":/icons/computer.svg"))
-        self.window.ui.tray_menu['screenshot'] = action
-        self.window.ui.tray_menu['screenshot'].triggered.connect(self.make_screenshot)
+        tray_menu['screenshot'] = action
+        tray_menu['screenshot'].triggered.connect(self.make_screenshot)
 
-        # exit
-        action = QAction(trans("menu.file.exit"), self.window)
+        action = QAction(trans("menu.file.exit"), w)
         action.setIcon(QIcon(":/icons/logout.svg"))
-        self.window.ui.tray_menu['exit'] = action
-        self.window.ui.tray_menu['exit'].triggered.connect(app.quit)
+        tray_menu['exit'] = action
+        tray_menu['exit'].triggered.connect(app.quit)
 
-        menu = QMenu(self.window)
-        menu.addAction(self.window.ui.tray_menu['restore'])
-        menu.addAction(self.window.ui.tray_menu['new'])
-        menu.addAction(self.window.ui.tray_menu['scheduled'])
-        menu.addAction(self.window.ui.tray_menu['open_notepad'])
-        menu.addAction(self.window.ui.tray_menu['screenshot'])
-        menu.addAction(self.window.ui.tray_menu['update'])
-        menu.addAction(self.window.ui.tray_menu['exit'])
-        self.icon.activated.connect(self.window.tray_toggle)
+        menu = QMenu(w)
+        menu.addAction(tray_menu['restore'])
+        menu.addAction(tray_menu['new'])
+        menu.addAction(tray_menu['scheduled'])
+        menu.addAction(tray_menu['open_notepad'])
+        menu.addAction(tray_menu['screenshot'])
+        menu.addAction(tray_menu['update'])
+        menu.addAction(tray_menu['exit'])
+        self.icon.activated.connect(w.tray_toggle)
         self.icon.setContextMenu(menu)
         self.icon.show()
 
@@ -165,25 +156,33 @@ class Tray:
         """Show notepad menu"""
         if not self.is_tray:
             return
-        self.window.ui.tray_menu['open_notepad'].setVisible(True)
+        action = self.window.ui.tray_menu.get('open_notepad')
+        if action and not action.isVisible():
+            action.setVisible(True)
 
     def hide_notepad_menu(self):
         """Hide notepad menu"""
         if not self.is_tray:
             return
-        self.window.ui.tray_menu['open_notepad'].setVisible(False)
+        action = self.window.ui.tray_menu.get('open_notepad')
+        if action and action.isVisible():
+            action.setVisible(False)
 
     def show_schedule_menu(self):
         """Show schedule menu"""
         if not self.is_tray:
             return
-        self.window.ui.tray_menu['scheduled'].setVisible(True)
+        action = self.window.ui.tray_menu.get('scheduled')
+        if action and not action.isVisible():
+            action.setVisible(True)
 
     def hide_schedule_menu(self):
         """Hide schedule menu"""
         if not self.is_tray:
             return
-        self.window.ui.tray_menu['scheduled'].setVisible(False)
+        action = self.window.ui.tray_menu.get('scheduled')
+        if action and action.isVisible():
+            action.setVisible(False)
 
     def update_schedule_tasks(self, tasks: int = 0):
         """
@@ -194,8 +193,10 @@ class Tray:
         if not self.is_tray:
             return
         if tasks > 0:
-            info = trans("menu.tray.scheduled") + ": {}".format(tasks)
-            self.window.ui.tray_menu['scheduled'].setText(info)
+            action = self.window.ui.tray_menu['scheduled']
+            info = f"{trans('menu.tray.scheduled')}: {tasks}"
+            if action.text() != info:
+                action.setText(info)
             self.show_schedule_menu()
         else:
-            self.hide_schedule_menu()
+            self.hide_schedule_menu()
\ No newline at end of file
