@@ -6,13 +6,17 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.08.11 00:00:00                  #
+# Updated Date: 2025.08.19 07:00:00                  #
 # ================================================== #
 
 import json
 import os
 import re
 from datetime import datetime
+
+from PySide6 import QtCore, QtGui
+from PySide6.QtWidgets import QApplication
+
 from pygpt_net.core.locale import Locale
 
 locale = None
@@ -259,21 +263,33 @@ def mem_clean():
     """
     Clean memory by removing unused variables
     """
+    return  # temporary disabled
+
     import sys, gc
     ok = False
     try:
         gc.collect()
     except Exception:
         pass
+        
+    try:
+        QApplication.sendPostedEvents(None, QtCore.QEvent.DeferredDelete)
+        QApplication.processEvents(QtCore.QEventLoop.AllEvents, 50)
+    except Exception:
+        pass
+
+    try:
+        QtGui.QPixmapCache.clear()
+    except Exception:
+        pass
+    
     try:
         if sys.platform.startswith("linux"):
             import ctypes, ctypes.util
-            libc_path = ctypes.util.find_library("c") or "libc.so.6"
-            libc = ctypes.CDLL(libc_path, use_errno=True)
+            libc = ctypes.CDLL(ctypes.util.find_library("c") or "libc.so.6")
             if hasattr(libc, "malloc_trim"):
-                libc.malloc_trim.argtypes = [ctypes.c_size_t]
-                libc.malloc_trim.restype = ctypes.c_int
-                ok = bool(libc.malloc_trim(0))
+                libc.malloc_trim(0)
+                ok = True
         elif sys.platform == "win32":
             import ctypes, ctypes.wintypes
             kernel32 = ctypes.WinDLL("kernel32", use_last_error=True)
